@@ -30,6 +30,7 @@
 #include <gdk/gdkx.h>
 
 #include <libxfce4util/libxfce4util.h>
+#include <libxfce4ui/libxfce4ui.h>
 #include <xfconf/xfconf.h>
 
 #include "xfce-mime-window.h"
@@ -51,7 +52,11 @@ static void
 mime_window_dialog_response (GtkWidget *dialog,
                              gint       response_id)
 {
-    gtk_main_quit ();
+    if (response_id == GTK_RESPONSE_HELP)
+        xfce_dialog_show_help_with_version (GTK_WINDOW (dialog), "xfce4-settings", "mime",
+                                            NULL, XFCE4_SETTINGS_VERSION_SHORT);
+    else
+        gtk_main_quit ();
 }
 
 
@@ -69,7 +74,7 @@ main (gint argc, gchar **argv)
     xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
 
     /* initialize Gtk+ */
-    if(!gtk_init_with_args (&argc, &argv, NULL, entries, PACKAGE, &error))
+    if (!gtk_init_with_args (&argc, &argv, NULL, entries, PACKAGE, &error))
     {
         if (G_LIKELY (error))
         {
