@@ -47,6 +47,11 @@
 #include <gio/gdesktopappinfo.h>
 #endif
 
+#include <gdk/gdk.h>
+#ifdef GDK_WINDOWING_X11
+#include <gdk/gdkx.h>
+#endif
+
 #include "xfce-mime-helper.h"
 #include "xfce-mime-helper-utils.h"
 
@@ -140,7 +145,7 @@ substitute_binary (const gchar *commands,
         }
       else if (binary != NULL)
         {
-          tmp = exo_str_replace (*s, "%B", binary);
+          tmp = xfce_str_replace (*s, "%B", binary);
           g_free (*s);
           *t++ = tmp;
         }
@@ -155,41 +160,42 @@ substitute_binary (const gchar *commands,
 }
 
 
+
 /**
  * Substitute env command usage.
  * For launchers that modify the env, such as snaps, this is required
  * to get a functional command from the commands_with_parameter. Otherwise
  * the launcher will only run `env`, quietly doing nothing.
  */
-static gchar**
-substitute_env (const gchar *commands,
-                const gchar *commands_with_parameter,
-                const gchar *binary)
+static gchar **
+substitute_env(const gchar *commands,
+               const gchar *commands_with_parameter,
+               const gchar *binary)
 {
   gchar **result;
 
-  result = substitute_binary (commands, binary);
+  result = substitute_binary(commands, binary);
 
-  if (G_UNLIKELY(*result != NULL && exo_str_is_equal (*result, "env")))
+  if (G_UNLIKELY(*result != NULL && g_strcmp0 (*result, "env") == 0))
+  {
+    gchar **replaced;
+    gchar *command = xfce_str_replace(commands_with_parameter, "%s", "");
+    gchar *cleaned = xfce_str_replace(command, "\"\"", "");
+
+    replaced = substitute_binary(cleaned, binary);
+    if (*replaced != NULL && g_strcmp0 (*replaced, "env") != 0)
     {
-      gchar **replaced;
-      gchar  *command = exo_str_replace (commands_with_parameter, "%s", "");
-      gchar  *cleaned = exo_str_replace (command, "\"\"", "");
-
-      replaced = substitute_binary (cleaned, binary);
-      if (*replaced != NULL && !exo_str_is_equal (*replaced, "env"))
-        {
-          g_strfreev (result);
-          result = replaced;
-        }
-      else
-        {
-          g_strfreev (replaced);
-        }
-
-      g_free (cleaned);
-      g_free (command);
+      g_strfreev(result);
+      result = replaced;
     }
+    else
+    {
+      g_strfreev(replaced);
+    }
+
+    g_free(cleaned);
+    g_free(command);
+  }
 
   return result;
 }
@@ -221,7 +227,7 @@ xfce_mime_helper_new (const gchar *id,
 
   /* verify the type of the desktop file */
   str = xfce_rc_read_entry_untranslated (rc, "Type", NULL);
-  if (G_UNLIKELY (!exo_str_is_equal (str, "X-XFCE-Helper")))
+  if (G_UNLIKELY (g_strcmp0 (str, "X-XFCE-Helper") != 0))
     goto failed;
 
   /* determine the category of the helper */
@@ -231,13 +237,13 @@ xfce_mime_helper_new (const gchar *id,
 
   /* determine the name of the helper */
   str = xfce_rc_read_entry (rc, "Name", NULL);
-  if (G_UNLIKELY (exo_str_is_empty (str)))
+  if (G_UNLIKELY (xfce_str_is_empty (str)))
     goto failed;
   helper->name = g_strdup (str);
 
   /* determine the icon of the helper */
   str = xfce_rc_read_entry_untranslated (rc, "Icon", NULL);
-  if (G_LIKELY (!exo_str_is_empty (str)))
+  if (G_LIKELY (!xfce_str_is_empty (str)))
     helper->icon = g_strdup (str);
 
   /* determine the commands */
@@ -245,7 +251,7 @@ xfce_mime_helper_new (const gchar *id,
   if (G_UNLIKELY (commands == NULL))
     goto failed;
 
-  commands_with_flag = exo_str_replace (commands, ";", " %s;");
+  commands_with_flag = xfce_str_replace (commands, ";", " %s;");
 
   /* determine the commands (with parameter) */
   commands_with_parameter = xfce_rc_read_entry_untranslated (rc, "X-XFCE-CommandsWithParameter", NULL);
@@ -380,7 +386,8 @@ xfce_mime_helper_get_command (const XfceMimeHelper *helper)
 static void
 set_environment (gchar *display)
 {
-  g_setenv ("DISPLAY", display, TRUE);
+  if (display != NULL)
+    g_setenv ("DISPLAY", display, TRUE);
 }
 
 /**
@@ -404,18 +411,18 @@ xfce_mime_helper_execute (XfceMimeHelper   *helper,
 {
   gint64        previous;
   gint64        current;
-  GdkDisplay   *display;
+  GdkDisplay   *display = NULL;
   gboolean      succeed = FALSE;
   GError       *err = NULL;
   gchar       **commands;
   gchar       **argv;
   gchar        *command;
-  gchar        *display_name;
+  gchar        *display_name = NULL;
   guint         n;
   gint          status;
   gint          result;
   gint          pid;
-  gchar        *real_parameter = NULL;
+  const gchar  *real_parameter = parameter;
 
   // FIXME: startup-notification
 
@@ -427,43 +434,23 @@ xfce_mime_helper_execute (XfceMimeHelper   *helper,
   if (G_UNLIKELY (screen == NULL))
     screen = gdk_screen_get_default ();
 
-  if (parameter != NULL)
-    {
-      if (helper->category == XFCE_MIME_HELPER_WEBBROWSER || helper->category == XFCE_MIME_HELPER_FILEMANAGER)
-        {
-          /* escape characters which do not belong into an URI/URL */
-          real_parameter = g_uri_escape_string (parameter, ":/?#[]@!$&'()*+,;=%", TRUE);
-        }
-      else if (g_str_has_prefix (real_parameter, "mailto:"))
-        {
-          /* strip the mailto part if needed */
-          real_parameter = g_strdup (parameter + 7);
-        }
-      else
-        {
-          real_parameter = g_strdup (parameter);
-        }
-    }
+  /* strip the mailto part if needed */
+  if (real_parameter != NULL && g_str_has_prefix (real_parameter, "mailto:"))
+    real_parameter = parameter + 7;
 
   /* determine the command set to use */
-  if (exo_str_is_flag (real_parameter))
-    {
-      commands = helper->commands_with_flag;
-    }
-  else if (exo_str_is_empty (real_parameter))
-    {
-      commands = helper->commands;
-    }
-  else
-    {
-      commands = helper->commands_with_parameter;
-    }
+  if (real_parameter != NULL && g_str_has_prefix (real_parameter, "-")) {
+    commands = helper->commands_with_flag;
+  } else if (xfce_str_is_empty (real_parameter)) {
+    commands = helper->commands;
+  } else {
+    commands = helper->commands_with_parameter;
+  }
 
   /* verify that we have atleast one command */
   if (G_UNLIKELY (*commands == NULL))
     {
       g_set_error (error, G_SPAWN_ERROR, G_SPAWN_ERROR_INVAL, _("No command specified"));
-      g_free (real_parameter);
       return FALSE;
     }
 
@@ -474,7 +461,7 @@ xfce_mime_helper_execute (XfceMimeHelper   *helper,
       g_clear_error (&err);
 
       /* parse the command */
-      command = !exo_str_is_empty (real_parameter) ? exo_str_replace (commands[n], "%s", real_parameter) : g_strdup (commands[n]);
+      command = !xfce_str_is_empty (real_parameter) ? xfce_str_replace (commands[n], "%s", real_parameter) : g_strdup (commands[n]);
       succeed = g_shell_parse_argv (command, NULL, &argv, &err);
       g_free (command);
 
@@ -483,8 +470,11 @@ xfce_mime_helper_execute (XfceMimeHelper   *helper,
         continue;
 
       /* set the display variable */
+#ifdef GDK_WINDOWING_X11
       display = gdk_screen_get_display (screen);
-      display_name = g_strdup (gdk_display_get_name (display));
+      if (display != NULL && GDK_IS_X11_DISPLAY (display))
+        display_name = g_strdup (gdk_display_get_name (display));
+#endif /* GDK_WINDOWING_X11 */
 
       /* try to run the command */
       succeed = g_spawn_async (NULL,
@@ -553,7 +543,6 @@ xfce_mime_helper_execute (XfceMimeHelper   *helper,
   if (G_UNLIKELY (!succeed))
     g_propagate_error (error, err);
 
-  g_free (real_parameter);
   return succeed;
 }
 
@@ -866,13 +855,13 @@ xfce_mime_helper_database_set_default (XfceMimeHelperDatabase *database,
           xfce_rc_set_group (rc, "Default Applications");
 
           for (i = 0; mimetypes[i] != NULL; i++)
-            if (!exo_str_is_empty (mimetypes[i]))
+            if (!xfce_str_is_empty (mimetypes[i]))
               xfce_rc_write_entry (rc, mimetypes[i], filename);
 
           xfce_rc_set_group (rc, "Added Associations");
 
           for (i = 0; mimetypes[i] != NULL; i++)
-            if (!exo_str_is_empty (mimetypes[i]))
+            if (!xfce_str_is_empty (mimetypes[i]))
               {
                 entry = g_strconcat (filename, ";", NULL);
                 xfce_rc_write_entry (rc, mimetypes[i], entry);
@@ -998,13 +987,13 @@ xfce_mime_helper_database_clear_default (XfceMimeHelperDatabase *database,
           xfce_rc_set_group (rc, "Default Applications");
 
           for (i = 0; mimetypes[i] != NULL; i++)
-            if (!exo_str_is_empty (mimetypes[i]))
+            if (!xfce_str_is_empty (mimetypes[i]))
               xfce_rc_delete_entry (rc, mimetypes[i], FALSE);
 
           xfce_rc_set_group (rc, "Added Associations");
 
           for (i = 0; mimetypes[i] != NULL; i++)
-            if (!exo_str_is_empty (mimetypes[i]))
+            if (!xfce_str_is_empty (mimetypes[i]))
               xfce_rc_delete_entry (rc, mimetypes[i], FALSE);
 
           g_strfreev (mimetypes);
@@ -1039,7 +1028,7 @@ clear_bad_entry (XfceRc *rc,
 
           for (i = 0; values[i] != NULL; i++)
             {
-              if (!exo_str_is_empty(values[i]) && g_strcmp0(values[i], filename) != 0)
+              if (!xfce_str_is_empty(values[i]) && g_strcmp0(values[i], filename) != 0)
                 {
                   list = g_slist_append (list, g_strdup(values[i]));
                 }
@@ -1206,7 +1195,7 @@ xfce_mime_helper_database_set_custom (XfceMimeHelperDatabase *database,
 
   g_return_if_fail (XFCE_MIME_IS_HELPER_DATABASE (database));
   g_return_if_fail (category < XFCE_MIME_HELPER_N_CATEGORIES);
-  g_return_if_fail (!exo_str_is_empty (command));
+  g_return_if_fail (!xfce_str_is_empty (command));
 
   /* determine the spec for the custom helper */
   category_string = xfce_mime_helper_category_to_string (category);
